EpeeEntry

Struct EpeeEntry 

pub struct EpeeEntry<'encoding, 'parent, B: BytesLike<'encoding>> { /* private fields */ }
An item with an EPEE-encoded object.

Implementations

Source

impl<'encoding, 'parent, B: BytesLike<'encoding>> EpeeEntry<'encoding, 'parent, B>

pub fn kind(&self) -> Type

The type of object this entry represents.

pub fn len(&self) -> usize

The amount of items present within this entry.

pub fn fields(self) -> Result<FieldIterator<'encoding, 'parent, B>, EpeeError>

Iterate over the fields within this object.

pub fn iterate(self) -> Result<ArrayIterator<'encoding, 'parent, B>, EpeeError>

Get an iterator of all items within this container.

If you want to index a specific item, you may use .iterate()?.nth(i)?. An index method isn’t provided as each index operation is of O(n) complexity and single indexes SHOULD NOT be used. Only exposing iterate attempts to make this clear to the user.

pub fn to_i64(self) -> Result<i64, EpeeError>

Get the current item as an i64.

pub fn to_i32(self) -> Result<i32, EpeeError>

Get the current item as an i32.

pub fn to_i16(self) -> Result<i16, EpeeError>

Get the current item as an i16.

pub fn to_i8(self) -> Result<i8, EpeeError>

Get the current item as an i8.

pub fn to_u64(self) -> Result<u64, EpeeError>

Get the current item as a u64.

pub fn to_u32(self) -> Result<u32, EpeeError>

Get the current item as a u32.

pub fn to_u16(self) -> Result<u16, EpeeError>

Get the current item as a u16.

pub fn to_u8(self) -> Result<u8, EpeeError>

Get the current item as a u8.

pub fn to_f64(self) -> Result<f64, EpeeError>

Get the current item as an f64.

pub fn to_str(self) -> Result<String<'encoding, B>, EpeeError>

Get the current item as a ‘string’ (represented as a B).

pub fn to_fixed_len_str( self, len: usize, ) -> Result<String<'encoding, B>, EpeeError>

Get the current item as a ‘string’ (represented as a B) of a specific length.

This will error if the result is not actually the expected length.

pub fn to_bool(self) -> Result<bool, EpeeError>

Get the current item as a bool.