pub struct Epee<'encoding, B: BytesLike<'encoding>> { /* private fields */ }Expand description
A decoder for an EPEE-encoded object.
Implementations
Sourceimpl<'encoding, B: BytesLike<'encoding>> Epee<'encoding, B>
impl<'encoding, B: BytesLike<'encoding>> Epee<'encoding, B>
Sourcepub fn entry(&mut self) -> Result<EpeeEntry<'encoding, '_, B>, EpeeError>
pub fn entry(&mut self) -> Result<EpeeEntry<'encoding, '_, B>, EpeeError>
Obtain an EpeeEntry representing the encoded object.
This takes a mutable reference as Epee is the owned object representing the decoder’s
state. However, this is not eligible to be called again after consumption. Multiple calls to
this function will cause an error to be returned.