pub struct EpeeEntry<'encoding, 'parent, B: BytesLike<'encoding>> { /* private fields */ }Expand description
An item with an EPEE-encoded object.
Implementations
Sourceimpl<'encoding, 'parent, B: BytesLike<'encoding>> EpeeEntry<'encoding, 'parent, B>
impl<'encoding, 'parent, B: BytesLike<'encoding>> EpeeEntry<'encoding, 'parent, B>
Sourcepub fn fields(self) -> Result<FieldIterator<'encoding, 'parent, B>, EpeeError>
pub fn fields(self) -> Result<FieldIterator<'encoding, 'parent, B>, EpeeError>
Iterate over the fields within this object.
Sourcepub fn iterate(self) -> Result<ArrayIterator<'encoding, 'parent, B>, EpeeError>
pub fn iterate(self) -> Result<ArrayIterator<'encoding, 'parent, B>, EpeeError>
Get an iterator of all items within this container.
If you want to index a specific item, you may use .iterate()?.nth(i)?. An index method
isn’t provided as each index operation is of O(n) complexity and single indexes SHOULD NOT be
used. Only exposing iterate attempts to make this clear to the user.
Sourcepub fn to_str(self) -> Result<String<'encoding, B>, EpeeError>
pub fn to_str(self) -> Result<String<'encoding, B>, EpeeError>
Get the current item as a ‘string’ (represented as a B).